pub struct Instant(/* private fields */);Expand description
A measurement of a monotonically non-decreasing clock.
Opaque and useful with Duration.
Implementations
Sourceimpl Instant
impl Instant
Sourcepub fn duration_since(&self, earlier: Instant) -> Duration
pub fn duration_since(&self, earlier: Instant) -> Duration
Returns the amount of time elapsed from another instant to this one.
Sourcepub fn checked_duration_since(&self, earlier: Instant) -> Option<Duration>
pub fn checked_duration_since(&self, earlier: Instant) -> Option<Duration>
Returns Some(Duration) if earlier is earlier than self, or None otherwise.