pub struct PeriodicTimer<'a> { /* private fields */ }Expand description
Periodic timer wrapper.
Counts down and automatically reloads, generating an interrupt each cycle.
Implementations
Sourceimpl PeriodicTimer<'_>
impl PeriodicTimer<'_>
Sourcepub fn start_micros(&mut self, us: u32)
pub fn start_micros(&mut self, us: u32)
Start the periodic timer with the period in microseconds.
Sourcepub fn tick_elapsed(&self) -> bool
pub fn tick_elapsed(&self) -> bool
Check if a period has elapsed (interrupt pending).
Sourcepub fn clear_tick(&self)
pub fn clear_tick(&self)
Clear the tick interrupt flag.